Please use the following to cite the NiaClass library::

    @InProceedings{10.1007/978-3-030-78811-7_36,
    author="Pe{\v{c}}nik, Luka
    and Fister, Iztok
    and Fister Jr., Iztok",
    editor="Tan, Ying
    and Shi, Yuhui",
    title="NiaClass: Building Rule-Based Classification Models Using Nature-Inspired Algorithms",
    booktitle="Advances in Swarm Intelligence",
    year="2021",
    publisher="Springer International Publishing",
    address="Cham",
    pages="381--390"
}
